MockCoreOAuth class

Mock class for testing.

Inheritance

Constructors

MockCoreOAuth()

Properties

hasCachedAccountInformation → Future<bool>
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
mockAccessToken → String
final
mockIdToken → String
final
mockRefreshToken → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAccessToken() → Future<String?>
override
getIdToken() → Future<String?>
override
getRefreshToken() → Future<String?>
override
login({bool refreshIfAvailable = false}) → Future<Either<Failure, Token>>
override
logout({bool showPopup = true, bool clearCookies = true}) → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshToken() → Future<Either<Failure, Token>>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited