prompt property

String? prompt
final

Indicates the type of user interaction that is required. The only valid values at this time are login, none, consent, and select_account. If select_account is wanting to be used, the user must have at least signed in once and when logging out, the clearCookies value must be false.

Implementation

final String? prompt;